@@ -1,5 +1,5 @@
 /* BLINKENLIGHTS PROXY
- * version 0.99 date 2006-11-29
+ * version 0.100 date 2008-03-21
  * Copyright (C) 2003-2006 Stefan Schuermans <1stein@schuermans.info>
  * Copyleft: GNU public license - http://www.gnu.org/copyleft/gpl.html
  */
@@ -649,9 +649,9 @@ int addr_match( st_addr * p_addr, st_addr_range * p_range )
       if( (addr & mask) != (net & mask) )
         return 0;
       //check port
-      port = ntohl( p_addr->sa.sin.sin_port );
-      port_min = ntohl( p_range->range.in.port_min );
-      port_max = ntohl( p_range->range.in.port_max );
+      port = ntohs( p_addr->sa.sin.sin_port );
+      port_min = ntohs( p_range->range.in.port_min );
+      port_max = ntohs( p_range->range.in.port_max );
       if( port < port_min || port > port_max )
         return 0;
       //match
@@ -662,9 +662,9 @@ int addr_match( st_addr * p_addr, st_addr_range * p_range )
       //check host
       for( i = 0; i < 4; i++ )
       {
-        addr = ntohl( p_addr->sa.sin6.sin6_addr.in6_u.u6_addr32[i] );
-        net = ntohl( p_range->range.in6.net.in6_u.u6_addr32[i] );
-        mask = ntohl( p_range->range.in6.mask.in6_u.u6_addr32[i] );
+        addr = ntohs( p_addr->sa.sin6.sin6_addr.in6_u.u6_addr32[i] );
+        net = ntohs( p_range->range.in6.net.in6_u.u6_addr32[i] );
+        mask = ntohs( p_range->range.in6.mask.in6_u.u6_addr32[i] );
         if( (addr & mask) != (net & mask) )
           return 0;
       }
