@@ -1,5 +1,5 @@
 /* BLINKENLIGHTS PROXY
- * version 0.99 date 2006-11-29
+ * version 0.100 date 2008-03-21
  * Copyright (C) 2003-2006 Stefan Schuermans <1stein@schuermans.info>
  * Copyleft: GNU public license - http://www.gnu.org/copyleft/gpl.html
  */
@@ -28,7 +28,7 @@
 #include "output.h"
 #include "tools.h"
 
-#define BL_PROXY_VERSION_STR "version 0.99 date 2006-11-29"
+#define BL_PROXY_VERSION_STR "version 0.100 date 2008-03-21"
 
 //default listen address for control connections
 #define listen_af "in"
@@ -505,7 +505,7 @@ int main( int arg_cnt, char * * args )
           {
             //accept connection
             len = ctrl_conn_sock_addr_len;
-            ctrl_conn_socks[i] = accept( ctrl_listen_sock, p_ctrl_conn_sock_addr, &len );
+            ctrl_conn_socks[i] = accept( ctrl_listen_sock, p_ctrl_conn_sock_addr, (unsigned int *)&len );
             if( ctrl_conn_socks[i] != -1 )
             {
               //clear buffer
