@@ -1,5 +1,5 @@
 /* BLINKENLIGHTS PROXY
- * version 0.99 date 2006-11-29
+ * version 0.100 date 2008-03-21
  * Copyright (C) 2003-2006 Stefan Schuermans <1stein@schuermans.info>
  * Copyleft: GNU public license - http://www.gnu.org/copyleft/gpl.html
  */
@@ -865,7 +865,7 @@ void proto_send_frame( int sock, et_proto proto, st_addr * p_addr, st_format for
   memset( p_msg_data, 0, msg_data_len );
 
   //convert frame to new format
-  frame_convert( &p_frame->format, p_frame->p_msg_data, &format, p_msg_data );
+  frame_convert( &p_frame->format, (unsigned char *)p_frame->p_msg_data, &format, (unsigned char *)p_msg_data );
 
   //send new packet
   sendto( sock, p_msg, msg_len, 0, &p_addr->sa.sa, p_addr->sa_len );
